@@ -23,6 +23,7 @@
 #include <QCollator>
 #include <QProcess>
 
+#include "service/settings_manager.h"
 #include "base/command.h"
 #include "partman/libparted_util.h"
 #include "partman/os_prober.h"
@@ -202,16 +203,21 @@ void PartitionManager::doRefreshDevices(bool umount, bool enable_os_prober) {
 }
 
 void PartitionManager::doAutoPart(const QString& script_path) {
-  if (!QFile::exists(script_path)) {
-    qCritical() << "partition script file not found!" << script_path;
-    emit this->autoPartDone(false);
-    return;
-  }
-  const bool ok = RunScriptFile({kHookManagerFile, script_path});
-  emit this->autoPartDone(ok);
+    WriteInstallStatus(installStatus::Partitioning);
+
+    if (!QFile::exists(script_path)) {
+        qCritical() << "partition script file not found!" << script_path;
+        emit this->autoPartDone(false);
+        return;
+    }
+
+    const bool ok = RunScriptFile({kHookManagerFile, script_path});
+    emit this->autoPartDone(ok);
 }
 
 void PartitionManager::doManualPart(const OperationList& operations) {
+    WriteInstallStatus(installStatus::Partitioning);
+
   qDebug() << Q_FUNC_INFO << "\n" << "operations:" << operations;
   bool ok = true;
   bool isLvm2Pv = false;
