@@ -18,6 +18,8 @@ public:
     QRect primaryAvailableGeometry();
     int getMainWindowTopMargin();
     int getChildWindowTopMargin();
+    int adapterHeightMargin(int height, int Margin = 55);
+    bool is4KScreen();
 
     double getWidthZoomRatio() const;
     double getHeightZoomRatio() const;
@@ -32,6 +34,7 @@ private:
     void initConnection();
     void adapterWidth(int width);
     void adapterHeight(int height);
+    void getCurrentScreenResolution();
 
 private:
     ScreenAdaptationManager();
@@ -42,6 +45,7 @@ private:
     double      m_heightZoomRatio = 1;
     QRect       m_oldWindowRect;
     QRect       m_oldAvailabWindowRect;
+    QPoint      m_currentScreenResolution;
 };
 
 
