@@ -80,6 +80,12 @@ const char kDeepinOemDir[] = "/lib/live/mount/medium/oem";
 const char kDeepinOemCandidateDir[] = "/usr/lib/live/mount/medium/oem";
 const char kDeepinOemCandidateDir2[] = "/run/live/medium/oem";
 
+const char kDebugPxeDir[] = "/tmp/pxemode";
+const char kUbuntuPxeDir[] = "/cdrom/pxemode";
+const char kDeepinPxeDir[] = "/lib/live/mount/medium/pxemode";
+const char kDeepinPxeCandidateDir[] = "/usr/lib/live/mount/medium/pxemode";
+const char kDeepinPxeCandidateDir2[] = "/run/live/medium/pxemode";
+
 // Filename of oem settings
 const char kOemSettingsFilename[] = "settings.ini";
 
@@ -130,6 +136,24 @@ QDir GetOemDir() {
     return QDir(g_oem_dir);
 }
 
+QDir GetPxeDir() {
+    QString g_oem_dir;
+    if (QDir(kDebugPxeDir).exists()) {
+        g_oem_dir = kDebugPxeDir;
+    } else if (QDir(kUbuntuPxeDir).exists()) {
+        g_oem_dir = kUbuntuPxeDir;
+    } else if (QDir(kDeepinPxeDir).exists()) {
+        g_oem_dir = kDeepinPxeDir;
+    } else if (QDir(kDeepinPxeCandidateDir).exists()) {
+        g_oem_dir = kDeepinPxeCandidateDir;
+    } else {
+        g_oem_dir = kDeepinPxeCandidateDir2;
+    }
+
+    qDebug() << "PXE_DIR=" << g_oem_dir;
+    return QDir(g_oem_dir);
+}
+
 QString GetOemLicenseDir() {
     QString oem_license_dir = GetOemDir().path() + "/licenses";
     return  QFileInfo(oem_license_dir).exists() ? oem_license_dir : RESOURCES_DIR"/licenses";
@@ -206,7 +230,7 @@ bool isPexInstall() {
     cmd_file.open(QIODevice::ReadOnly);
     if (!cmd_file.isOpen()) {
         qCritical() << "isPexInstall: Failed to open file. /proc/cmdline";
-        return true;   // 如果没有读到文件，无法做出是否为pxe的判断， 则始终不加载网络模块，防止产生网络问题
+        return false;   // 如果没有读到文件，无法做出是否为pxe的判断， 则始终不加载网络模块，防止产生网络问题
     }
     QString info = cmd_file.readAll();
     if (!info.contains("nfsroot")) {
@@ -694,6 +718,11 @@ void AddConfigFile() {
         settingsList << oem_file;
     }
 
+    const QString pxe_file = GetPxeDir().absoluteFilePath(kOemSettingsFilename);
+    if (QFile::exists(pxe_file) && isPexInstall()) {
+        settingsList << pxe_file;
+    }
+
     const QString policy_file = QString("%1/disk_policy/settings_%2.ini")
             .arg(GetOemDir().path(), GetDiskPolicyArgs());
     if (QFile::exists(policy_file)) {
@@ -1075,4 +1104,74 @@ void WriteSaveUserData(bool issave)
     AppendToConfigFile("DI_SAVE_DATA", issave);
 }
 
+// 记录安装器安装阶段脚本执行阶段状态埋点
+void WriteInstallStatus(installStatus status)
+{
+    AppendToConfigFile("DI_INSTALL_STATUS", int(status));
+}
+
+QString getInstallStatusName()
+{
+    installStatus status = installStatus(GetSettingsInt("DI_INSTALL_STATUS"));
+    switch (status) {
+        case installStatus::Preparing: {
+            return ::QObject::tr("Preparing...");
+        }
+        case installStatus::Partitioning: {
+            return ::QObject::tr("Partitioning...");
+        }
+        case installStatus::DecompressingFiles:{
+            return ::QObject::tr("Decompressing files...");
+        }
+        case installStatus::InstallingSystem:{
+            return ::QObject::tr("Installing system...");
+        }
+        case installStatus::InitialBackupInProgress:{
+            return ::QObject::tr("Initial backup in progress...");
+        }
+        case installStatus::FinishingInstallation:{
+            return ::QObject::tr("Finishing installation...");
+        }
+    }
+
+    return "";
+}
+
+QString verifyCheck()
+{
+    return GetSettingsString("DI_DEEPIN_VERIFY_STATUS");
+}
+
+void SetSettingBoosl(const QString &key, const bool value)
+{
+    AppendToConfigFile(key, value);
+}
+
+bool handleVerify(const QString &sourceFilePath, const QString& verifyFilePath, QString &err) {
+    qInfo() << "handle verify start...";
+    QString cmd = GetSettingsString("DI_DEEPIN_SQUASHFS_VERIFY");
+    QStringList args = {"-f", sourceFilePath, "-s", verifyFilePath};
+
+    QString out;
+    if (QFileInfo::exists(cmd)) {
+        if (!SpawnCmd(cmd, args, out, err)) {
+            err = QString("%1 handle verify faield. out: %2.  %3.").arg(cmd + " " + args.join(" "), out, err);
+            return false;
+        }
+    }
+
+    qInfo() << QString("Command: %1 succeed.").arg(cmd + " " + args.join(" "));
+    return true;
+}
+
+void SetSettingString(const QString &key, const QString &value)
+{
+    AppendToConfigFile(key, value);
+}
+
+bool isDebug()
+{
+    return GetSettingsBool("system_debug");
+}
+
 }  // namespace installer
