@@ -283,7 +283,9 @@ bool Delegate::createPartition(const Partition::Ptr partition,
                                FsType               fs_type,
                                const QString&       mount_point,
                                qint64               total_sectors,
-                               const QString&       label)
+                               const QString&       label,
+                               bool                 isLvm,
+                               bool flag)
 {
     Device::Ptr device = findDevice(partition->device_path);
 
@@ -303,7 +305,7 @@ bool Delegate::createPartition(const Partition::Ptr partition,
 
     if (partition_type == PartitionType::Normal) {
         return createPrimaryPartition(partition, partition_type, align_start, fs_type,
-                                      mount_point, total_sectors, label);
+                                      mount_point, total_sectors, label, isLvm, flag);
     }
     else if (partition_type == PartitionType::Logical) {
         return createLogicalPartition(partition, align_start, fs_type, mount_point,
@@ -451,7 +453,9 @@ bool Delegate::createPrimaryPartition(const Partition::Ptr partition,
                                       FsType               fs_type,
                                       const QString&       mount_point,
                                       qint64               total_sectors,
-                                      const QString&       label)
+                                      const QString&       label,
+                                      bool                 isLvm,
+                                      bool flag)
 {
     // Policy:
     // * If new primary partition is contained in or intersected with
@@ -522,13 +526,16 @@ bool Delegate::createPrimaryPartition(const Partition::Ptr partition,
     new_partition->fs          = fs_type;
     new_partition->mount_point = mount_point;
     new_partition->label       = label;
+    new_partition->is_lvm      = isLvm;
 
-    int partition_number = AllocPrimaryPartitionNumber(device);
-    if (partition_number < 0) {
-        qCritical() << "Failed to allocate primary partition number!";
-        return false;
+    if (device->device_type == DeviceType::VGDevice || !new_partition->is_lvm) {
+        int partition_number = AllocPrimaryPartitionNumber(device);
+        if (partition_number < 0) {
+            qCritical() << "Failed to allocate primary partition number!";
+            return false;
+        }
+        new_partition->changeNumber(partition_number);
     }
-    new_partition->changeNumber(partition_number);
 
     if (fs_type == FsType::Recovery) {
         // Hide recovery partition
@@ -549,6 +556,9 @@ bool Delegate::createPrimaryPartition(const Partition::Ptr partition,
         else {
             new_partition->start_sector = partition->start_sector;
         }
+        // Align to nearest MebiBytes.        
+        if (!flag && (mount_point != kMountPointBoot) && (fs_type != FsType::EFI)) AlignPartition(new_partition);
+
         new_partition->end_sector =
             qMin(partition->end_sector, total_sectors + new_partition->start_sector);
     }
@@ -562,10 +572,11 @@ bool Delegate::createPrimaryPartition(const Partition::Ptr partition,
             new_partition->start_sector =
                 qMax(partition->start_sector, partition->end_sector - total_sectors);
         }
+
+        if (!flag && (mount_point != kMountPointBoot) && (fs_type != FsType::EFI)) AlignPartition(new_partition);
     }
 
-    // Align to nearest MebiBytes.
-    AlignPartition(new_partition);
+    if (flag) AlignPartition(new_partition);
 
     // Check partition sector range.
     // Also check whether partition size is less than 1MiB or not.
@@ -897,6 +908,9 @@ void Delegate::updateMountPoint(const Partition::Ptr partition,
         operations_.append(operation);
         operation->applyToVisual(device);
     }
+    else {
+        partition->mount_point = "";
+    }
 }
 
 bool Delegate::reCalculateExtPartBoundary(PartitionAction       action,
