@@ -114,6 +114,12 @@ MainWindow::MainWindow(QWidget* parent)
 
     qApp->installEventFilter(this);
 
+    if (!verifyCheck()) {
+        stacked_layout_->setCurrentWidget(m_installResultsFrame);
+        m_installResultsFrame->showInstallFailedFrame();
+        return;
+    }
+
     for (auto it = m_frames.begin(); it != m_frames.end();) {
         if ((*it)->shouldDisplay()) {
             break;
@@ -585,10 +591,6 @@ void MainWindow::initPages() {
   privilege_error_frame_ = new PrivilegeErrorFrame(this);
   privilege_error_frame_->setFocusPolicy(Qt::NoFocus);
 
-  system_info_frame_ = new SystemInfoFrame(this);
-  system_info_frame_->setFocusPolicy(Qt::NoFocus);
-  stacked_layout_->addWidget(system_info_frame_);
-
   timezone_frame_ = new TimezoneFrame(this);
   timezone_frame_->setFocusPolicy(Qt::NoFocus);
   stacked_layout_->addWidget(timezone_frame_);
@@ -620,7 +622,6 @@ void MainWindow::initPages() {
       virtual_machine_frame_,
       network_frame_,
       timezone_frame_,
-      system_info_frame_,
       m_selectComponentFrame,
       partition_frame_,
 #endif // QT_DEBUG
@@ -926,6 +927,32 @@ void MainWindow::updateFrameLabelPreviousState(bool allow)
     }
 }
 
+bool MainWindow::verifyCheck()
+{
+    QStringList sourceFileList = GetSettingsStringList("DI_INITRD_SOURCE_PATH");
+    QStringList verifyFileList = GetSettingsStringList("DI_INITRD_VERIFY_PATH");
+    for (int i = 0; i < sourceFileList.size(); i++) {
+        QString sourceFile = QString("%1/../%2").arg(GetOemDir().absolutePath(), sourceFileList.at(i));
+        QString verifyFile = "";
+        if (!verifyFileList.isEmpty()) {
+            verifyFile = QString("%1/../%2").arg(GetOemDir().absolutePath(),
+                                                     verifyFileList.at(i < verifyFileList.size() ? i : verifyFileList.size() - 1));
+        }
+
+        QString err;
+        if (!handleVerify(sourceFile, verifyFile, err)) {
+            qCritical() << "deepin squashfs verify: " << err;
+            // 兼容安装器的调试模式
+            if (!GetSettingsBool("system_debug")) {
+                SetSettingString("DI_DEEPIN_VERIFY_STATUS", sourceFile);
+                return false;
+            }
+        }
+    }
+
+    return true;
+}
+
 FrameInterface *MainWindow::getFrameInterface(QStandardItem *item) const
 {
     for (auto it = m_frameModelItemMap.begin(); it != m_frameModelItemMap.end(); ++it) {
